==> apache-druid-33.0.0-src.tar.gz: apache-druid-33.0.0-src/web-console/src/druid-models/index.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export * from './async-query/async-query';
export * from './compaction-config/compaction-config';
export * from './compaction-dynamic-config/compaction-dynamic-config';
export * from './compaction-status/compaction-status';
export * from './coordinator-dynamic-config/coordinator-dynamic-config';
export * from './dart/dart-query-entry';
export * from './datasource/datasource';
export * from './dimension-spec/dimension-spec';
export * from './druid-engine/druid-engine';
export * from './execution/execution';
export * from './external-config/external-config';
export * from './filter/filter';
export * from './flatten-spec/flatten-spec';
export * from './index-spec/index-spec';
export * from './ingest-query-pattern/ingest-query-pattern';
export * from './ingestion-spec/ingestion-spec';
export * from './input-format/input-format';
export * from './input-source/input-source';
export * from './load-rule/load-rule';
export * from './lookup-spec/lookup-spec';
export * from './metric-spec/metric-spec';
export * from './overlord-dynamic-config/overlord-dynamic-config';
export * from './query-context/query-context';
export * from './segment/segment';
export * from './stages/stages';
export * from './supervisor-status/supervisor-status';
export * from './task/task';
export * from './time/time';
export * from './timestamp-spec/timestamp-spec';
export * from './transform-spec/transform-spec';
export * from './workbench-query/workbench-query';

==> apache-druid-35.0.0-src.tar.gz: apache-druid-35.0.0-src/web-console/src/druid-models/index.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

export * from './array-ingest-mode/array-ingest-mode';
export * from './async-query/async-query';
export * from './compaction-config/compaction-config';
export * from './compaction-dynamic-config/compaction-dynamic-config';
export * from './compaction-status/compaction-status';
export * from './console/console';
export * from './coordinator-dynamic-config/coordinator-dynamic-config';
export * from './dart/dart-query-entry';
export * from './datasource/datasource';
export * from './dimension-spec/dimension-spec';
export * from './druid-engine/druid-engine';
export * from './execution/execution';
export * from './external-config/external-config';
export * from './filter/filter';
export * from './flatten-spec/flatten-spec';
export * from './index-spec/index-spec';
export * from './ingest-query-pattern/ingest-query-pattern';
export * from './ingestion-spec/ingestion-spec';
export * from './input-format/input-format';
export * from './input-source/input-source';
export * from './load-rule/load-rule';
export * from './lookup-spec/lookup-spec';
export * from './metric-spec/metric-spec';
export * from './native-json-query/native-json-query-completions';
export * from './overlord-dynamic-config/overlord-dynamic-config';
export * from './query-context/query-context';
export * from './segment/segment';
export * from './stages/stages';
export * from './supervisor-status/supervisor-status';
export * from './task/task';
export * from './time/time';
export * from './timestamp-spec/timestamp-spec';
export * from './transform-spec/transform-spec';
export * from './workbench-query/workbench-query';
